==> eslint-config-cssnano-1.0.0.tgz: package/index.js <==
module.exports = {
    'rules': {
        'brace-style': [2, '1tbs', {'allowSingleLine': false}],
        'camelcase': [2],
        'comma-spacing': [2],
        'consistent-return': [2],
        'curly': [2, 'all'],
        'dot-notation': [2],
        'eol-last': [2],
        'eqeqeq': [2],
        'handle-callback-err': [2],
        'indent': [2, 4],
        'new-cap': [2],
        'new-parens': [2],
        'no-alert': [2],
        'no-caller': [2],
        'no-const-assign': [2],
        'no-constant-condition': [2],
        'no-dupe-args': [2],
        'no-dupe-keys': [2],
        'no-empty': [2],
        'no-empty-character-class': [2],
        'no-eval': [2],
        'no-irregular-whitespace': [2],
        'no-labels': [2],
        'no-lonely-if': [2],
        'no-multiple-empty-lines': [2],
        'no-new': [2],
        'no-octal': [2],
        'no-proto': [2],
        'no-redeclare': [2],
        'no-shadow': [2],
        'no-shadow-restricted-names': [2],
        'no-sparse-arrays': [2],
        'no-undef': [2],
        'no-unreachable': [2],
        'no-unused-vars': [2],
        'no-useless-call': [2],
        'no-var': [2],
        'no-void': [2],
        'no-warning-comments': [2],
        'no-with': [2],
        'object-curly-spacing': [2, 'never'],
        'quote-props': [2, 'as-needed'],
        'prefer-arrow-callback': [2],
        'radix': [2],
        'semi': [2, 'always'],
        'semi-spacing': [2],
        'space-after-keywords': [2, 'always'],
        'space-before-function-paren': [2, 'always'],
        'space-before-blocks': [2, 'always'],
        'space-return-throw-case': [2],
        'spaced-comment': [2, 'always'],
        'strict': [2, 'global'],
        'yoda': [2, 'never']
    },
    'ecmaFeatures': {
        'arrowFunctions': true,
        'binaryLiterals': true,
        'blockBindings': true,
        'classes': true,
        'defaultParams': true,
        'destructuring': true,
        'experimentalObjectRestSpread': true,
        'forOf': true,
        'generators': true,
        'modules': true,
        'objectLiteralComputedProperties': true,
        'objectLiteralDuplicateProperties': true,
        'objectLiteralShorthandMethods': true,
        'objectLiteralShorthandProperties': true,
        'octalLiterals': true,
        'regexUFlag': true,
        'regexYFlag': true,
        'restParams': true,
        'spread': true,
        'superInFunctions': true,
        'templateStrings': true
    },
    'env': {
        'node': true,
        'es6': true
    }
};

==> eslint-config-cssnano-2.0.0.tgz: package/index.js <==
module.exports = {
    'rules': {
        'brace-style': [2, '1tbs', {'allowSingleLine': false}],
        'camelcase': [2],
        'comma-spacing': [2],
        'curly': [2, 'all'],
        'dot-notation': [2],
        'eol-last': [2],
        'eqeqeq': [2],
        'handle-callback-err': [2],
        'indent': [2, 4],
        'keyword-spacing': [2],
        'new-cap': [2],
        'new-parens': [2],
        'no-alert': [2],
        'no-caller': [2],
        'no-const-assign': [2],
        'no-constant-condition': [2],
        'no-dupe-args': [2],
        'no-dupe-keys': [2],
        'no-empty': [2],
        'no-empty-character-class': [2],
        'no-eval': [2],
        'no-irregular-whitespace': [2],
        'no-labels': [2],
        'no-lonely-if': [2],
        'no-multiple-empty-lines': [2],
        'no-new': [2],
        'no-octal': [2],
        'no-proto': [2],
        'no-redeclare': [2],
        'no-shadow': [2],
        'no-shadow-restricted-names': [2],
        'no-sparse-arrays': [2],
        'no-undef': [2],
        'no-unreachable': [2],
        'no-unused-vars': [2],
        'no-useless-call': [2],
        'no-var': [2],
        'no-void': [2],
        'no-warning-comments': [2],
        'no-with': [2],
        'object-curly-spacing': [2, 'never'],
        'quote-props': [2, 'as-needed'],
        'prefer-arrow-callback': [2],
        'radix': [2],
        'semi': [2, 'always'],
        'semi-spacing': [2],
        'space-before-function-paren': [2, 'always'],
        'space-before-blocks': [2, 'always'],
        'spaced-comment': [2, 'always'],
        'strict': [2, 'global'],
        'yoda': [2, 'never']
    },
    'parserOptions': {
        'ecmaVersion': 6,
        'sourceType': 'module',
        'ecmaFeatures': {
            'experimentalObjectRestSpread': true
        },
    },
    'env': {
        'node': true,
        'es6': true
    }
};
